@@ -58,6 +58,8 @@ def create_responsive_navbar(file_path: str, brand_name: str = "公司名称", n
             {"name": "服务", "href": "#services", "active": False},
             {"name": "联系", "href": "#contact", "active": False}
         ]
+    elif not nav_items:
+        return "导航栏未生成：nav_items 为空，已跳过注入导航组件"
 
     # 归一化单个导航项，避免 KeyError
     def _normalize_item(raw: object, index: int) -> tuple[dict, bool]:
