@@ -33,13 +33,19 @@ from pathlib import Path
 from htmlgen_mcp.agents.smart_web_agent import SmartWebAgent
 from htmlgen_mcp.nas_storage import get_nas_storage
 from htmlgen_mcp.nas_log_manager import get_nas_log_manager, ensure_job_log, log_progress, query_progress
+from htmlgen_mcp.prompt_enhancer import enhance_prompt_for_real_data
 from datetime import datetime
 
 # 使用 NAS 作为默认存储路径
 NAS_PATH = os.environ.get("NAS_STORAGE_PATH", "/app/mcp-servers/mcp-servers/html_agent")
+# 项目根目录：优先使用 WEB_AGENT_PROJECT_ROOT 环境变量，否则使用 NAS_PATH/projects
 DEFAULT_PROJECT_ROOT = os.path.abspath(
     os.environ.get("WEB_AGENT_PROJECT_ROOT", f"{NAS_PATH}/projects")
 )
+# 是否自动生成项目子目录（可通过环境变量控制）
+AUTO_CREATE_PROJECT_DIR = os.environ.get("AUTO_CREATE_PROJECT_DIR", "true").lower() == "true"
+# 默认的文件上传URL（可通过环境变量 UPLOAD_URL 覆盖）
+DEFAULT_UPLOAD_URL = os.environ.get("UPLOAD_URL", "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile")
 DEFAULT_MODEL = os.environ.get("WEB_AGENT_MODEL", "qwen3-coder-plus-2025-09-23")
 DEFAULT_BASE_URL = os.environ.get(
     "OPENAI_BASE_URL", "https://dashscope.aliyuncs.com/compatible-mode/v1"
@@ -76,6 +82,7 @@ _PROGRESS_LOG_BY_ID: dict[str, str] = {}
 _PROGRESS_LOG_BY_JOB: dict[str, str] = {}
 _JOB_REGISTRY: dict[str, Dict[str, Any]] = {}
 _CONTEXT_CACHE_BY_ID: dict[str, Dict[str, Any]] = {}
+_CONTEXT_ID_BY_PLAN: dict[str, str] = {}
 
 
 def _job_state_path(job_id: str) -> Path:
@@ -134,6 +141,18 @@ def _load_job_states() -> None:
 _load_job_states()
 
 
+def _load_job_state_from_disk(job_id: str) -> Optional[Dict[str, Any]]:
+    path = _job_state_path(job_id)
+    if not path.exists():
+        return None
+    try:
+        data = json.loads(path.read_text(encoding="utf-8"))
+        data.setdefault("job_id", job_id)
+        return data
+    except Exception:
+        return None
+
+
 def _context_cache_path(context_id: str) -> Path:
     return CONTEXT_CACHE_DIR / f"{context_id}.json"
 
@@ -172,9 +191,47 @@ def _resolve_cached_context(context_id: Optional[str]) -> Optional[Dict[str, Any
     return None
 
 
-def _resolve_project_directory(project_root: Optional[str]) -> str:
-    base = project_root or DEFAULT_PROJECT_ROOT
-    abs_path = os.path.abspath(base)
+def _resolve_project_directory(project_root: Optional[str], project_name: Optional[str] = None) -> str:
+    """
+    解析项目目录路径
+    
+    Args:
+        project_root: 项目根目录或完整路径
+        project_name: 项目名称（可选）
+    
+    Returns:
+        完整的项目目录路径
+    """
+    if project_root:
+        # 如果提供了 project_root
+        if os.path.isabs(project_root):
+            # 绝对路径：直接使用
+            abs_path = project_root
+        else:
+            # 相对路径：相对于默认根目录
+            # 如果 project_root 看起来像项目名（不含/），则作为子目录
+            if '/' not in project_root and '\\' not in project_root:
+                abs_path = os.path.join(DEFAULT_PROJECT_ROOT, project_root)
+            else:
+                # 包含路径分隔符，作为相对路径处理
+                abs_path = os.path.abspath(os.path.join(DEFAULT_PROJECT_ROOT, project_root))
+    else:
+        # 没有提供 project_root，使用默认根目录
+        base = DEFAULT_PROJECT_ROOT
+        
+        # 如果提供了 project_name 且启用了自动创建子目录
+        if project_name and AUTO_CREATE_PROJECT_DIR:
+            # 清理项目名称，去除特殊字符
+            safe_name = "".join(c for c in project_name if c.isalnum() or c in (' ', '-', '_', '.'))
+            safe_name = safe_name.strip().replace(' ', '_')
+            if safe_name:
+                abs_path = os.path.join(base, safe_name)
+            else:
+                abs_path = base
+        else:
+            abs_path = base
+    
+    # 创建目录
     os.makedirs(abs_path, exist_ok=True)
     return abs_path
 
@@ -402,16 +459,13 @@ def _execute_plan(
 @mcp.tool()
 async def execute_plan(
     plan_id: str,
-    *,
-    project_root: str,
+    project_root: Optional[str] = None,
     # auto_plan: bool = False,  # 已禁用，没有实际作用
     # confirm_each_step: bool = False,  # 后台执行模式下用户无法交互确认
     # show_code: bool = False,  # 后台执行时用户看不到输出
     # verbose: bool = False,  # 后台执行时详细日志意义不大
-    save_output: bool = False,
+    # save_output: bool = True,  # 已固定为 True，始终创建进度日志
     progress_log: Optional[str] = None,
-    auto_upload: bool = False,
-    upload_url: str = "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile",
 ) -> Dict[str, Any]:
     """执行网页构建计划，始终以后台模式运行。
 
@@ -420,56 +474,76 @@ async def execute_plan(
         由 plan_site 工具返回的计划ID，用于从缓存或文件系统中查找对应的执行计划。
         例如："a1b2c3d4e5f6..." 这样的32位十六进制字符串。
 
-    - project_root: 网站文件生成的目标目录路径
+    - project_root: 网站文件生成的目标目录路径（可选）
         指定项目文件的输出位置，可以是绝对路径或相对路径。
         例如："/path/to/my/website" 或 "./my-project"
         如果目录不存在，系统会自动创建。
-
-    - save_output: 是否保存执行过程的详细输出到文件
-        True: 会自动创建进度日志文件，记录所有执行步骤和结果
-        False: 不创建进度日志文件，只保留基本的任务状态信息
-        建议在调试或需要详细追踪时设置为 True
+        如果未指定，将使用计划中保存的项目目录。
 
     - progress_log: 自定义进度日志文件的保存路径（可选）
         如果指定：使用该路径保存进度日志（JSONL格式）
-        如果未指定但 save_output=True：自动在 ~/.mcp/make_web/progress_logs 目录创建时间戳命名的日志文件（可通过环境变量覆盖）
-        如果都未指定：不记录进度日志
+        如果未指定：自动在 ~/.mcp/make_web/progress_logs 目录创建时间戳命名的日志文件（可通过环境变量覆盖）
         路径可以是绝对路径或相对于 project_root 的相对路径
 
-    - auto_upload: 是否在构建完成后自动上传到MCP服务器
-        True: 构建完成后自动打包为ZIP并上传，返回访问URL
-        False: 仅构建，不上传
-        默认为 False
-
-    - upload_url: 文件上传API地址
-        默认为 "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile"
-        只在 auto_upload=True 时生效
+        注意：进度日志始终会被创建，以便使用 get_progress 工具查询任务进度。
 
     执行流程：
     - 任务始终在后台异步执行，立即返回 job_id 和 progress_log 路径
     - 使用 get_progress(job_id=..., limit=...) 可以实时查询执行状态和进度
-    - 支持通过进度日志文件追踪详细的执行步骤和结果
-    - 执行完成后可以获取完整的执行报告和生成的文件列表
-    - 🎯 新增：auto_upload=True时，构建完成(100%)后自动上传并返回访问URL
+    - 系统会自动记录详细的执行步骤和结果到进度日志文件
+    - 执行完成后可以获取完整的执行报告、生成文件列表，以及自动上传结果
     """
     try:
-        project_dir = _resolve_project_directory(project_root)
-
-        # 移除 auto_plan 检查，因为参数已被移除
+        # 如果没有提供project_root，尝试从缓存中获取
+        if not project_root:
+            cached_by_id = _PLAN_CACHE_BY_ID.get(plan_id)
+            if cached_by_id and cached_by_id.get("project_directory"):
+                project_root = cached_by_id["project_directory"]
+            else:
+                # 尝试从文件中读取
+                possible_paths = [
+                    PLAN_CACHE_DIR / f"{plan_id}.json",
+                    PLAN_CACHE_DIR / f"simple_site_plan_{plan_id}.json",
+                ]
+                for path in possible_paths:
+                    if path.exists():
+                        try:
+                            plan_data = json.loads(path.read_text(encoding="utf-8"))
+                            project_root = plan_data.get("project_directory")
+                            if project_root:
+                                break
+                        except Exception:
+                            pass
+                
+                if not project_root:
+                    # 使用默认根目录，但不添加子目录
+                    project_root = None
+        
+        # 从计划中获取项目名称（如果有）
+        project_name = None
+        if plan_id:
+            cached_plan = _PLAN_CACHE_BY_ID.get(plan_id)
+            if cached_plan:
+                # 尝试从缓存中获取项目名称
+                project_name = cached_plan.get("site_title") or cached_plan.get("project_name")
+        
+        project_dir = _resolve_project_directory(project_root, project_name)
 
+        # 进度日志始终启用
         if progress_log:
+            # 用户指定了自定义日志路径
             progress_log_path = (
                 progress_log
                 if os.path.isabs(progress_log)
                 else os.path.join(project_dir, progress_log)
             )
-        elif save_output:
+        else:
+            # 自动生成日志文件
             progress_log_path = os.path.join(
                 PROGRESS_LOG_DIR, f"agent_progress_{int(time.time())}.jsonl"
             )
-        else:
-            progress_log_path = None
 
+        # 尝试创建日志文件
         if progress_log_path:
             try:
                 Path(progress_log_path).parent.mkdir(parents=True, exist_ok=True)
@@ -477,9 +551,10 @@ async def execute_plan(
             except Exception:
                 progress_log_path = None
 
+        # save_output 固定为 True
         agent = _build_agent(
             project_dir,
-            save_output=save_output,
+            save_output=True,
         )
 
         # 通过 plan_id 查询计划
@@ -568,29 +643,20 @@ async def execute_plan(
                 agent,
                 plan_dict,
                 progress_log_path=progress_log_path,
-                auto_upload=auto_upload,
-                upload_url=upload_url,
             )
         )
 
-        if auto_upload:
-            message = (
-                "执行已在后台启动（含自动上传）：调用 get_progress(job_id='{}', limit=20) "
-                "可获取构建和上传进度。完成后将返回网站访问URL。"
-            ).format(job_id)
-        else:
-            message = (
-                "执行已在后台启动：调用 get_progress(job_id='{}', limit=20) "
-                "或传入 progress_log='{}' 可获取实时进度"
-            ).format(job_id, progress_log_path or "<未启用进度日志>")
+        message = (
+            "执行已在后台启动（含自动上传）：调用 get_progress(job_id='{}', limit=20) "
+            "或传入 progress_log='{}' 可获取实时进度与上传结果"
+        ).format(job_id, progress_log_path or "<未启用进度日志>")
 
         return {
             "status": "started",
             "job_id": job_id,
             "plan_id": plan_id,
             "progress_log": progress_log_path,
-            "auto_upload": auto_upload,
-            "upload_url": upload_url if auto_upload else None,
+            "upload_url": DEFAULT_UPLOAD_URL,
             "message": message,
         }
     except Exception as exc:
@@ -607,8 +673,6 @@ async def _run_execution_job(
     plan_dict: Dict[str, Any],
     *,
     progress_log_path: Optional[str],
-    auto_upload: bool = False,
-    upload_url: str = "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile",
 ) -> None:
     job_info = _JOB_REGISTRY.get(job_id)
     if not job_info:
@@ -626,49 +690,7 @@ async def _run_execution_job(
         job_info["completed_at"] = time.time()
         _persist_job_state(job_id)
 
-        # 🎯 关键：任务完成后自动上传
-        if auto_upload and job_info.get("project_directory"):
-            try:
-                # 记录上传开始
-                job_info["upload_status"] = "uploading"
-                _persist_job_state(job_id)
-
-                upload_result = await upload_project_to_mcp_server(
-                    folder_path=job_info["project_directory"], upload_url=upload_url
-                )
-
-                # 记录上传结果
-                job_info["upload_result"] = upload_result
-                job_info["upload_status"] = upload_result["status"]
-                if upload_result["status"] == "success":
-                    job_info["website_url"] = upload_result["url"]
-                    job_info["upload_completed_at"] = time.time()
-
-                    # 添加到进度日志
-                    if progress_log_path:
-                        upload_event = {
-                            "timestamp": time.time(),
-                            "type": "upload_completed",
-                            "status": "success",
-                            "website_url": upload_result["url"],
-                            "message": upload_result["message"],
-                        }
-                        try:
-                            with open(
-                                progress_log_path, "a", encoding="utf-8"
-                            ) as log_file:
-                                log_file.write(
-                                    json.dumps(upload_event, ensure_ascii=False)
-                                )
-                                log_file.write("\n")
-                        except Exception:
-                            pass
-
-                _persist_job_state(job_id)
-            except Exception as upload_exc:
-                job_info["upload_status"] = "failed"
-                job_info["upload_error"] = str(upload_exc)
-                _persist_job_state(job_id)
+        await _handle_auto_upload(job_id, job_info, progress_log_path)
 
     except Exception as exc:
         job_info["status"] = "failed"
@@ -682,37 +704,70 @@ async def _run_execution_job(
         _persist_job_state(job_id)
 
 
+async def _handle_auto_upload(
+    job_id: str,
+    job_info: Dict[str, Any],
+    progress_log_path: Optional[str],
+) -> None:
+    project_dir = job_info.get("project_directory")
+    if not project_dir:
+        return
+
+    job_info["upload_status"] = "uploading"
+    _persist_job_state(job_id)
+
+    try:
+        upload_result = await upload_project_to_mcp_server(
+            folder_path=project_dir,
+            upload_url=DEFAULT_UPLOAD_URL,
+        )
+
+        job_info["upload_result"] = upload_result
+        job_info["upload_status"] = upload_result.get("status")
+
+        if upload_result.get("status") == "success":
+            job_info["website_url"] = upload_result.get("url")
+            job_info["upload_completed_at"] = time.time()
+
+            if progress_log_path:
+                upload_event = {
+                    "timestamp": time.time(),
+                    "type": "upload_completed",
+                    "status": "success",
+                    "website_url": upload_result.get("url"),
+                    "message": upload_result.get("message"),
+                }
+                try:
+                    with open(progress_log_path, "a", encoding="utf-8") as log_file:
+                        log_file.write(json.dumps(upload_event, ensure_ascii=False))
+                        log_file.write("\n")
+                except Exception:
+                    pass
+
+    except Exception as exc:
+        job_info["upload_status"] = "failed"
+        job_info["upload_error"] = str(exc)
+    finally:
+        _persist_job_state(job_id)
+
+
 @mcp.tool()
 async def create_simple_site(
     description: str,
     site_title: str = "我的网站",
-    project_root: Optional[str] = None,
-    model: Optional[str] = None,
-    context_id: Optional[str] = None,
     context_content: Optional[str] = None,
 ) -> Dict[str, Any]:
     """使用AI分析需求，生成简单但美观的网站计划。
 
-    ⚠️ 重要参数说明：
+    参数说明：
     - description: 网站需求描述，例如"个人作品展示网站"、"小餐厅官网"、"博客网站"等
-    - site_title: 网站标题
-    - context_content: 🔥 核心参数！用于传递网页制作所需的所有原始数据内容
+    - site_title: 网站标题，默认为"我的网站"
+    - context_content: 可选，用于传递网页制作所需的所有原始数据内容
       * 例如：咖啡馆列表、产品介绍、菜单内容、地址信息、营业时间等
       * 这是AI获取具体业务信息的唯一渠道，请务必将查询到的详细信息完整传入
       * 如果有地图查询结果、API返回数据等，都应该放在这个参数中
       * 格式可以是文本、JSON字符串或结构化数据的字符串表示
 
-    其他参数：
-    - project_root: 项目根目录，缺省使用默认目录
-    - model: 使用的AI模型，缺省使用默认模型
-    - context_id: 可选，引用已缓存的上下文快照以复用历史资料
-
-    图片配置参数（可选）：
-    - image_style: 图片风格 (professional|artistic|minimal|vibrant|luxury)
-    - image_topics: 用户自定义的图片主题列表，如 ["modern office", "team collaboration"]
-    - include_gallery: 是否在网站中包含图片画廊功能
-    - image_provider: 图片提供商 (pollinations|dicebear|robohash)
-
     返回值说明：
     - status: 操作状态 ("success" 或 "error")
     - plan_id: 生成的计划唯一标识符，用于后续执行
@@ -731,31 +786,17 @@ async def create_simple_site(
     这样AI就能基于真实数据来生成个性化的网站内容。
     """
     try:
-        # 使用指定模型或默认模型
-        used_model = model or DEFAULT_MODEL
+        # 使用默认模型
+        used_model = DEFAULT_MODEL
 
-        # 确定项目目录
-        if project_root:
-            if not os.path.isabs(project_root):
-                project_directory = os.path.join(DEFAULT_PROJECT_ROOT, project_root)
-            else:
-                project_directory = project_root
-        else:
-            # 使用站点标题作为目录名
-            safe_title = "".join(
-                c if c.isalnum() or c in "._-" else "_" for c in site_title
-            )
-            project_directory = os.path.join(DEFAULT_PROJECT_ROOT, safe_title)
+        # 使用新的路径解析逻辑，默认在共享目录下按标题创建项目
+        project_directory = _resolve_project_directory(None, site_title)
 
         # 处理上下文
         context_data = ""
-        actual_context_id = context_id
+        actual_context_id: Optional[str] = None
 
-        if context_id and context_id in _CONTEXT_CACHE_BY_ID:
-            # 使用缓存的上下文
-            cached_context = _CONTEXT_CACHE_BY_ID[context_id]
-            context_data = cached_context.get("content", "")
-        elif context_content:
+        if context_content:
             # 使用新提供的上下文内容
             context_data = context_content
             # 生成新的上下文ID并缓存
@@ -776,42 +817,45 @@ async def create_simple_site(
             force_single_page=True,
         )
 
-        # 构建针对简单网站的提示，包含上下文和图片要求
-        context_section = ""
+        # 如果有上下文内容，将其整合到描述中
+        enhanced_description = description
         if context_data:
-            context_section = f"""
+            enhanced_description = f"""{description}
 
-**上下文内容**:
+【必须使用的具体数据内容】：
 {context_data}
 
-**重要说明**: 请根据上述上下文内容来定制网站的具体内容，确保生成的网页与提供的信息高度匹配。"""
+【重要提示】：上述数据是真实的业务数据，必须完整准确地展示在网页中，不要生成虚构的示例内容。"""
 
-        simple_prompt = f"""请为以下需求设计一个简单但美观的网站：
+        # 构建改进的提示词，强调使用真实数据
+        simple_prompt = f"""请为以下需求创建一个网站，并严格使用提供的真实数据：
 
-**网站需求**: {description}
-**网站标题**: {site_title}{context_section}
+**网站标题**: {site_title}
+**具体需求和数据**: 
+{enhanced_description}
 
-**设计要求**:
-1. 保持简洁但要有视觉吸引力
-2. 使用轻量级CSS（不超过300行）
-3. 包含基础但实用的功能
-4. 响应式设计，适配移动端
-5. 良好的配色和排版
-6. 智能图片集成，根据内容类型匹配合适主题
-7. 如果有上下文内容，请充分利用这些信息来丰富网页内容
+**执行要求**：
+1. 【数据要求】如果提供了具体数据（如店铺列表、产品信息等），必须100%使用这些真实数据，不要创建虚构内容
+2. 【内容展示】将所有提供的数据项完整展示，使用合适的布局（如卡片、列表、表格等）
+3. 【样式设计】保持简洁美观，使用响应式设计
+4. 【代码限制】CSS不超过300行，避免复杂特效
+5. 【功能实现】包含基础交互功能（导航、滚动等）
 
-请生成一个包含3-6个步骤的简化执行计划，每个步骤要简洁明确。
-重点关注：页面结构、样式设计、图片集成、必要功能。避免复杂特效。
+**特别强调**：
+- 当创建HTML内容时，必须使用上面提供的真实数据
+- 不要生成"示例客户评价"、"虚拟定价方案"等占位内容
+- 如果是咖啡馆列表，就展示真实的咖啡馆名称和地址
+- 如果是产品信息，就展示真实的产品数据
+- 每个create_html_file或add_content_section工具调用时，都要包含真实数据
 
-输出格式要求：
-- 每个步骤都要具体可执行
-- 优先使用简单模板函数而非复杂模板
-- 注重实用性和美观性的平衡
-- 充分利用提供的上下文信息来生成个性化内容
+请生成3-6个步骤的执行计划，确保每个步骤都能正确使用提供的数据。
 """
 
         # 生成简化计划（仅规划，不执行）
-        plan = agent._get_execution_plan(simple_prompt)
+        # 传递强化后的提示词，确保AI使用真实数据
+        # 使用提示词增强器进一步强化
+        final_prompt = enhance_prompt_for_real_data(simple_prompt, context_data)
+        plan = agent._get_execution_plan(final_prompt)
 
         # 在计划中标记为简单网站类型和相关信息
         plan["site_type"] = "simple"
@@ -826,9 +870,8 @@ async def create_simple_site(
         plan_id = str(uuid.uuid4())
 
         # 构建完整的源描述（包含上下文）
-        source_description = description
-        if context_data:
-            source_description = f"{description}\n\n【附加内容】\n{context_data}"
+        # 使用enhanced_description以确保数据被传递
+        source_description = enhanced_description
 
         # 在计划中添加源描述字段
         plan["__source_description"] = source_description
@@ -844,13 +887,16 @@ async def create_simple_site(
             "plan_id": plan_id,
         }
 
+        if actual_context_id:
+            cached_entry["context_id"] = actual_context_id
+
         _PLAN_CACHE_BY_ID[plan_id] = cached_entry
         cache_key = (project_directory, description)
         _PLAN_CACHE[cache_key] = cached_entry
 
         # 将上下文信息关联到计划
         if actual_context_id:
-            _PROGRESS_LOG_BY_ID[plan_id] = actual_context_id
+            _CONTEXT_ID_BY_PLAN[plan_id] = actual_context_id
 
         # 保存计划到文件
         plan_filename = f"simple_site_plan_{plan_id}.json"
@@ -954,6 +1000,20 @@ async def get_progress(
 
         if job_id:
             job_info = _JOB_REGISTRY.get(job_id)
+            if not job_info:
+                disk_state = _load_job_state_from_disk(job_id)
+                if disk_state:
+                    _JOB_REGISTRY[job_id] = disk_state
+                    job_info = disk_state
+                    progress_log_from_state = job_info.get("progress_log")
+                    if progress_log_from_state:
+                        progress_log_str = str(progress_log_from_state)
+                        _PROGRESS_LOG_BY_JOB[job_id] = progress_log_str
+                        plan_in_state = job_info.get("plan_id")
+                        if plan_in_state:
+                            _PROGRESS_LOG_BY_ID.setdefault(
+                                plan_in_state, progress_log_str
+                            )
             if job_info and not plan_id:
                 plan_id = job_info.get("plan_id")
             if job_id in _PROGRESS_LOG_BY_JOB:
@@ -1047,14 +1107,12 @@ async def get_progress(
                     "report": job_info.get("result", {}).get("report"),
                     "created_files": job_info.get("result", {}).get("created_files"),
                 }
-                # 添加上传结果信息
                 if job_info.get("upload_result"):
                     job_snapshot["upload_result"] = job_info.get("upload_result")
 
             if job_info.get("status") == "failed":
                 job_snapshot["error"] = job_info.get("error")
 
-            # 添加上传错误信息
             if job_info.get("upload_error"):
                 job_snapshot["upload_error"] = job_info.get("upload_error")
 
@@ -1072,13 +1130,11 @@ async def get_progress(
 @mcp.tool()
 async def upload_project_to_mcp_server(
     folder_path: str,
-    upload_url: str = "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile",
 ) -> Dict[str, Any]:
     """将项目文件夹打包成ZIP并上传到MCP服务器。
 
     参数说明：
     - folder_path: 项目文件夹的绝对路径
-    - upload_url: 上传API地址，默认为MCP服务器地址
 
     返回值：
     - status: 上传状态 ("success" 或 "error")
@@ -1126,7 +1182,7 @@ async def upload_project_to_mcp_server(
                     "file", f, filename=zip_filename, content_type="application/zip"
                 )
 
-                async with session.post(upload_url, data=data) as response:
+                async with session.post(DEFAULT_UPLOAD_URL, data=data) as response:
                     response_text = await response.text()
 
                     if response.status != 200:
